<?php

namespace HyperSoft\ElectronicDocument\Validator;

include_once(__DIR__ . '/clases/parametros/json.class.php');

abstract class Connection
{
    //<editor-fold desc="Business">

    //<editor-fold desc="Constants">
    const Version = '2019.07.11';
    //</editor-fold>

    //<editor-fold desc="Vars">
    private $json;
    //</editor-fold>

    //<editor-fold desc="Properties">
    public $Version = '1.0';
    private $rfcDistribuidor;
    private $idDistribuidor;
    //</editor-fold>

    //<editor-fold desc="Methods">
    public function Execute()
    {
        $this->GenerateJson();
        return $this->SendToRest();
    }

    public function GetJson()
    {
        $this->GenerateJson();
        return $this->json;
    }

    abstract protected function CalculateUrl();

    private function GenerateJson()
    {
        $object = $this;
        unset($object->json);
        unset($object->response);

        $json = new Json();

        $this->json = $json->Generate($object);
    }

    private function SendToRest()
    {
        $post['data'] = $this->json;
        $post['RfcDistribuidor'] = $this->rfcDistribuidor;
        $post['IdDistribuidor'] = $this->idDistribuidor;

        $postdata = http_build_query($post);
        $servidor = $this->CalculateUrl();

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $servidor);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $postdata);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $respuesta = curl_exec($ch);
        $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);
        $respuestaError = array();
        
        switch ($httpcode) {
            case 200:
                return json_decode($respuesta);
                break;
            case 404:
                $respuestaError["ProcessProviderResult"] = 0;
                $respuestaError["ErrorDescription"] = "Error 404 Not Found. El servidor está caido, no responde o fue colocado en otra Url";
                break;
            case 400:
                $respuestaError["ProcessProviderResult"] = 0;
                $respuestaError["ErrorDescription"] = "Error 400 Bad Request. El servidor no reconoce la petición http enviada";
                break;
            case 500:
                $respuestaError["ProcessProviderResult"] = 0;
                $respuestaError["ErrorDescription"] = "Error 500 Internal Server Error. El servidor ha generado un error.";
                break;
            case 403:
                $respuestaError["ProcessProviderResult"] = 0;
                $respuestaError["ErrorDescription"] = "Error 403 Forbiden. No tiene permisos para acceder a este recurso en el servidor.";
                break;
            default:
                $respuestaError["ProcessProviderResult"] = 0;
                $respuestaError["ErrorDescription"] = "Error desconocido de http ({$httpcode}). La petición al servidor generó un error desconocido.";
                break;
        }

        return json_decode(json_encode($respuestaError));

    }
    //</editor-fold>

    //</editor-fold>

    //<editor-fold desc="Factory">
    public function __construct($rfcDistribuidor, $idDistribuidor)
    {
        $this->rfcDistribuidor = $rfcDistribuidor;
        $this->idDistribuidor = $idDistribuidor;
    }
    //</editor-fold>
}