<?php

// Método para uso interno de este ejemplos
function file_get_contents_utf8($fn)
{
    $content = file_get_contents($fn);
    return mb_convert_encoding($content, 'UTF-8', mb_detect_encoding($content, 'UTF-8, ISO-8859-1', true));
}

// Método para uso interno de este ejemplos
function Get_Html_Group($title, $body)
{
    return
        '<div class="panel panel-primary">' .
        '<div class="panel-heading">' .
        '<h3 class="panel-title">' . $title . '</h3>' . '</div>' .
        '<div class="panel-body">' .
        '<table class="table">' .
        '<tbody>' . $body . '</tbody>' .
        '</table>' .
        '</div>' . '</div>';
}

// Método para uso interno de este ejemplos
function Get_Html_Row($title, $value = '')
{
    return '<tr>' . '<th scope="row" class="col-md-3">' . $title . '</th>' . "<td class=\"col-md-9\">{$value}</td>" . '</tr>' . '<tr>';
}

// Método para uso interno de este ejemplos
function base64_to_file($base64, $output_file)
{
    $file = fopen($output_file, 'wb');

    fwrite($file, base64_decode($base64));

    fclose($file);
}


include_once(__DIR__ . '/../../codigo/edv.php');

use HyperSoft\ElectronicDocument\Validator;

// Método que muestra la versión de la librería
function Version()
{
    //return '<h5><span class="label label-default text-right">Electronic Documento Validator - ' . Validator\Edv::Version .'</span></h5>';
    return '<span class="label label-default text-right">Electronic Documento Validator - ' . Validator\Edv::Version . '</span>';
}

// Método que muestra los datos del archivo validado
function Show_Archivo($respuesta)
{
    if (isset($respuesta->Archivo) == false) {
        return;
    }

    $body =
        Get_Html_Row('Nombre', $respuesta->Archivo->Nombre) .
        Get_Html_Row('Tamaño', number_format($respuesta->Archivo->Tamanio) . " bytes");

    echo Get_Html_Group('Archivo', $body);
}

// Método que muestra el error fatal que se haya presentando durante el proceso de validación
function Show_FatalError($respuesta)
{

    if (isset($respuesta->FatalError) == false) {
        return;
    }

    switch ($respuesta->FatalError->Tipo) {
        case Validator\FatalErrorType::None:
            $tipo = 'OK';
            break;

        case Validator\FatalErrorType::NotXmlFile:
            $tipo = 'NotXmlFile';
            break;

        case Validator\FatalErrorType::NotWellFormed:
            $tipo = 'NotWellFormed';
            break;

        case Validator\FatalErrorType::NotValid:
            $tipo = 'NotValid';
            break;

        case Validator\FatalErrorType::NotRootNode:
            $tipo = 'NotRootNode';
            break;

        case Validator\FatalErrorType::NotVersion:
            $tipo = 'NotVersion';
            break;


        case Validator\FatalErrorType::NotValidVersion:
            $tipo = 'NotValidVersion';
            break;

        case Validator\FatalErrorType::NotSupported:
            $tipo = 'NotSupported';
            break;

        case Validator\FatalErrorType::CanNotReadFile:
            $tipo = 'CanNotReadFile';
            break;

        case Validator\FatalErrorType::NotPrefix:
            $tipo = 'NotPrefix';
            break;

        default:
            throw new Exception('Valor no soportado');
    }

    $body = Get_Html_Row('Tipo', $tipo) . Get_Html_Row('Descripción', $respuesta->FatalError->Descripcion);

    echo Get_Html_Group('Error fatal', $body);
}

// Método que muestra como tener acceso al archivo PDF del resultado de la validación
function Show_Pdf($respuesta)
{
    if (isset($respuesta->ReportePdf) == false) {
        return;
    }

    base64_to_file($respuesta->ReportePdf, 'reporte.pdf');

    $body =
        'Para ver el reporte de validación, de clic <a href="reporte.pdf">aquí!</a>';

    echo Get_Html_Group('Reporte de validación - PDF', $body);
}

// Método que muestra los datos del CFDI
function Show_Documento($respuesta)
{
    if (isset($respuesta->Documento) == false) {
        return;
    }

    $body = '';

    if (isset($respuesta->Documento->Serie)) {
        $body = $body . Get_Html_Row('Versión', $respuesta->Documento->Version);
    }

    if (isset($respuesta->Documento->Serie)) {
        $body = $body . Get_Html_Row('Serie', $respuesta->Documento->Serie);
    }

    if (isset($respuesta->Documento->Folio)) {
        $body = $body . Get_Html_Row('Folio', $respuesta->Documento->Folio);
    }

    if (isset($respuesta->Documento->FechaEmision)) {
        $body = $body . Get_Html_Row('Fecha de emisión', $respuesta->Documento->FechaEmision);
    }

    if (isset($respuesta->Documento->StatusSat)) {

        switch ($respuesta->Documento->StatusSat) {
            case Validator\SatStatusType::UnKnow:
                $estado = 'Desconocido';
                break;

            case Validator\SatStatusType::NotFound:
                $estado = 'No encontrado';
                break;

            case Validator\SatStatusType::Active:
                $estado = 'Activo';
                break;

            case Validator\SatStatusType::Canceled:
                $estado = 'Cancelado';
                break;

            default:
                throw new UnexpectedValueException();
                break;

        }
        $body = $body . Get_Html_Row('Estado', $estado);
    }


    if (isset($respuesta->Documento->FechaCancelacion)) {
        $body = $body . Get_Html_Row('Fecha de cancelación', $respuesta->Documento->FechaCancelacion);
    }

    if (isset($respuesta->Documento->Tipo)) {
        $body = $body . Get_Html_Row('Tipo', $respuesta->Documento->Tipo);
    }

    if (isset($respuesta->Documento->NumeroCertificado)) {
        $body = $body . Get_Html_Row('N. de certificado', $respuesta->Documento->NumeroCertificado);
    }

    if (isset($respuesta->Documento->Sello)) {
        $body = $body . Get_Html_Row('Sello', $respuesta->Documento->Sello);
    }

    if (isset($respuesta->Documento->CadenaOriginal)) {
        $body = $body . Get_Html_Row('Cadena original', $respuesta->Documento->CadenaOriginal);
    }

    if (isset($respuesta->Documento->CadenaOriginalPac)) {
        $body = $body . Get_Html_Row('Cadena original PAC', $respuesta->Documento->CadenaOriginalPac);
    }

    if (isset($respuesta->Documento->Moneda)) {
        $body = $body . Get_Html_Row('Moneda', $respuesta->Documento->Moneda);
    }

    if (isset($respuesta->Documento->TipoCambio)) {
        $body = $body . Get_Html_Row('Moneda', $respuesta->Documento->TipoCambio);
    }

    echo Get_Html_Group('Documento', $body);
}

// Método que muestra los datos del EMISOR
function Show_Emisor($respuesta)
{
    if (isset($respuesta->Emisor) == false) {
        return;
    }

    $body = '';

    if (isset($respuesta->Emisor->Rfc)) {
        $body = $body . Get_Html_Row('RFC', $respuesta->Emisor->Rfc);
    }

    if (isset($respuesta->Emisor->Nombre)) {
        $body = $body . Get_Html_Row('Nombre', $respuesta->Emisor->Nombre);
    }

    echo Get_Html_Group('Emisor', $body);
}

// Método que muestra los datos del RECEPTOR
function Show_Receptor($respuesta)
{
    if (isset($respuesta->Emisor) == false) {
        return;
    }

    $body = '';

    if (isset($respuesta->Receptor->Rfc)) {
        $body = $body . Get_Html_Row('RFC', $respuesta->Receptor->Rfc);
    }

    if (isset($respuesta->Receptor->Nombre)) {
        $body = $body . Get_Html_Row('Nombre', $respuesta->Receptor->Nombre);
    }

    echo Get_Html_Group('Receptor', $body);
}

// Método que muestra el RESUMENT del proceso
function Show_Resumen($respuesta)
{

    if (isset($respuesta->Resumen) == false) {
        return;
    }

    $body =
        Get_Html_Row('Total de errores', $respuesta->Resumen->TotalErrores) .
        Get_Html_Row('Total de advertencias', $respuesta->Resumen->TotalAdvertencias) .
        Get_Html_Row('Total de sugerencias', $respuesta->Resumen->TotalSugerencias) .
        Get_Html_Row('Fecha de validación', $respuesta->Resumen->FechaValidacion) .
        Get_Html_Row('Tiempo de validación', $respuesta->Resumen->TiempoValidacion);

    echo Get_Html_Group('Resumen', $body);
}

// Método de uso general que muestra cada una de las validaciones realizadas
function Show_Validaciones($validaciones)
{

    $body = Get_Html_Row('<span class="label label-default">VALIDACIONES</span>');

    $count = count($validaciones);
    for ($i = 0; $i < $count; $i++) {
        switch ($validaciones[$i]->Tipo) {
            case Validator\ValidationErrorType::UnKnow:
                $tipo = 'Desconocido';
                break;

            case Validator\ValidationErrorType::None:
                $tipo = 'OK';
                break;

            case Validator\ValidationErrorType::Error:
                $tipo = 'Error';
                break;

            case Validator\ValidationErrorType::Warning:
                $tipo = 'Advertencia';
                break;

            case Validator\ValidationErrorType::Suggestion:
                $tipo = 'Sugerencia';
                break;

            default:
                throw new Exception('Valor no soportado');
        }

        $body = $body . Get_Html_Row("No. " . ($i + 1), "<b>{$tipo} - </b> {$validaciones[$i]->Descripcion}");
    }

    return $body;
}

// Método que muestra las validaciones hechas a la ESTRUCTURA del XML
function Show_Estructura($respuesta)
{
    if (isset($respuesta->Estructura) == false) {
        return;
    }

    $body =
        Get_Html_Row('Errores', $respuesta->Estructura->Errores) .
        Get_Html_Row('Advertencias', $respuesta->Estructura->Advertencias) .
        Get_Html_Row('Sugerencias', $respuesta->Estructura->Sugerencias);

    if (isset($respuesta->Estructura->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Estructura->Validaciones);
    }

    echo Get_Html_Group('Estructura', $body);
}

// Método que muestra las validaciones hechas al SELLO del documento
function Show_Sello($respuesta)
{
    if (isset($respuesta->Sello) == false) {
        return;
    }

    $body =
        Get_Html_Row('Errores', $respuesta->Sello->Errores) .
        Get_Html_Row('Advertencias', $respuesta->Sello->Advertencias) .
        Get_Html_Row('Sugerencias', $respuesta->Sello->Sugerencias);

    if (isset($respuesta->Sello->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Sello->Validaciones);
    }

    echo Get_Html_Group('Sello', $body);
}

// Método que muestra los datos del TIMBRE y las validaciones hechas al mismo.
function Show_Timbre($respuesta)
{
    if (isset($respuesta->Timbre) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Timbre->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Timbre->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Timbre->Sugerencias);

    $body = $body . Get_Html_Row('<span class="label label-default">DATOS</span>');

    if (isset($respuesta->Timbre->Version)) {
        $body = $body . Get_Html_Row('Versión', $respuesta->Timbre->Version);
    }

    if (isset($respuesta->Timbre->Uuid)) {
        $body = $body . Get_Html_Row('UUID', $respuesta->Timbre->Uuid);
    }

    if (isset($respuesta->Timbre->FechaTimbrado)) {
        $body = $body . Get_Html_Row('Fecha de timbrado', $respuesta->Timbre->FechaTimbrado);
    }

    if (isset($respuesta->Timbre->ProveedorAutorizadoRfc)) {
        $body = $body . Get_Html_Row('RFC del PAC', $respuesta->Timbre->ProveedorAutorizadoRfc);
    }

    if (isset($respuesta->Timbre->ProveedorAutorizado)) {
        $body = $body . Get_Html_Row('Proveedor autorizado', $respuesta->Timbre->ProveedorAutorizado);
    }

    if (isset($respuesta->Timbre->NumeroCertificadoSat)) {
        $body = $body . Get_Html_Row('No. certificado SAT', $respuesta->Timbre->NumeroCertificadoSat);
    }

    if (isset($respuesta->Timbre->SelloCfd)) {
        $body = $body . Get_Html_Row('Sello CFD', $respuesta->Timbre->SelloCfd);
    }

    if (isset($respuesta->Timbre->SelloSat)) {
        $body = $body . Get_Html_Row('Sello SAT', $respuesta->Timbre->SelloSat);
    }

    if (isset($respuesta->Timbre->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Timbre->Validaciones);
    }

    echo Get_Html_Group('Timbre', $body);
}

// Método que muestra los datos del CERTIFICADO y las validaciones hechas al mismo.
function Show_Certificado($respuesta)
{
    if (isset($respuesta->Certificado) == false) {
        return;
    }

    $body =
        Get_Html_Row('Errores', $respuesta->Certificado->Errores) .
        Get_Html_Row('Advertencias', $respuesta->Certificado->Advertencias) .
        Get_Html_Row('Sugerencias', $respuesta->Certificado->Sugerencias);

    $body = $body . Get_Html_Row('<span class="label label-default">DATOS</span>');

    if (isset($respuesta->Certificado->Version)) {
        $body = $body . Get_Html_Row('Versión', $respuesta->Certificado->Version);
    }

    if (isset($respuesta->Certificado->NumeroSerie)) {
        $body = $body . Get_Html_Row('No. de serie', $respuesta->Certificado->NumeroSerie);
    }

    if (isset($respuesta->Certificado->Identificador)) {
        $body = $body . Get_Html_Row('Identificador', $respuesta->Certificado->Identificador);
    }

    if (isset($respuesta->Certificado->EmitidoPor)) {
        $body = $body . Get_Html_Row('Emitido por', $respuesta->Certificado->EmitidoPor);
    }

    if (isset($respuesta->Certificado->EmitidoPara)) {
        $body = $body . Get_Html_Row('Emitido para', $respuesta->Certificado->EmitidoPara);
    }

    if (isset($respuesta->Certificado->ValidoDesde)) {
        $body = $body . Get_Html_Row('Válido desde', $respuesta->Certificado->ValidoDesde);
    }

    if (isset($respuesta->Certificado->ValidoHasta)) {
        $body = $body . Get_Html_Row('Valido hasta', $respuesta->Certificado->ValidoHasta);
    }

    if (isset($respuesta->Certificado->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Certificado->Validaciones);
    }

    echo Get_Html_Group('Certificado', $body);
}

// Método que muestra los datos del TOTAL y las validaciones hechas al mismo.
function Show_Totales($respuesta)
{
    if (isset($respuesta->Totales) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Totales->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Totales->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Totales->Sugerencias);

    $body = $body . Get_Html_Row('<span class="label label-default">DATOS</span>');

    if (isset($respuesta->Totales->SubTotal)) {
        $body = $body . Get_Html_Row('SubTotal', $respuesta->Totales->SubTotal);
    }

    if (isset($respuesta->Totales->Descuento)) {
        $body = $body . Get_Html_Row('Descuento', $respuesta->Totales->Descuento);
    }

    if (isset($respuesta->Totales->ImpuestoTrasladado)) {
        $body = $body . Get_Html_Row('Impuesto trasladado', $respuesta->Totales->ImpuestoTrasladado);
    }

    if (isset($respuesta->Totales->ImpuestoRetenido)) {
        $body = $body . Get_Html_Row('Impuesto retenido', $respuesta->Totales->ImpuestoRetenido);
    }

    if (isset($respuesta->Totales->ImpuestoLocalTrasladado)) {
        $body = $body . Get_Html_Row('Impuesto local trasladado', $respuesta->Totales->ImpuestoLocalTrasladado);
    }

    if (isset($respuesta->Totales->ImpuestoLocalRetenido)) {
        $body = $body . Get_Html_Row('Impuesto local retenido', $respuesta->Totales->ImpuestoLocalRetenido);
    }

    if (isset($respuesta->Totales->Tua)) {
        $body = $body . Get_Html_Row('TUA', $respuesta->Totales->Tua);
    }

    if (isset($respuesta->Totales->Total)) {
        $body = $body . Get_Html_Row('Total', $respuesta->Totales->Total);
    }

    if (isset($respuesta->Totales->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Totales->Validaciones);
    }

    echo Get_Html_Group('Totales', $body);
}

// Método que muestra las validaciones hechas con los SCHEMA.
function Show_Schema($respuesta)
{
    if (isset($respuesta->Schema) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Schema->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Schema->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Schema->Sugerencias) .

        Get_Html_Row('<span class="label label-default">DATOS</span>') . Get_Html_Row('Nodos', $respuesta->Schema->Nodos) . Get_Html_Row('Atributos',
            $respuesta->Schema->Atributos);

    if (isset($respuesta->Schema->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Schema->Validaciones);
    }

    echo Get_Html_Group('Schema', $body);
}

// Método que muestra las validaciones hechas con respecto a la L.C.O.
function Show_Lco($respuesta)
{
    if (isset($respuesta->Lco) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Lco->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Lco->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Lco->Sugerencias);

    if (isset($respuesta->Lco->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Lco->Validaciones);
    }

    echo Get_Html_Group('L.C.O.', $body);
}

// Método que muestra las validaciones hechas con respecto al archivo CSD.TXT
function Show_Csd($respuesta)
{
    if (isset($respuesta->Csd) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Csd->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Csd->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Csd->Sugerencias);

    if (isset($respuesta->Csd->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Csd->Validaciones);
    }

    echo Get_Html_Group('C.S.D.', $body);
}

// Método que muestra las validaciones hechas con el LISTADO DE CONTRIBUYENTES CON OPERACIONES INEXISTENTES
// para conocer mas del tema puedes leer aquí:
// http://www.facturando.mx/blog/index.php/2014/11/04/que-son-las-operaciones-inexistentes/
function Show_Lcoi($respuesta)
{
    if (isset($respuesta->Lcoi) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Lcoi->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Lcoi->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Lcoi->Sugerencias);

    if (isset($respuesta->Lcoi->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Lcoi->Validaciones);
    }

    echo Get_Html_Group('L.C.O.I.', $body);
}

// Método que muestra las validaciones hechas en el servidor del SAT
function Show_Sat($respuesta)
{
    if (isset($respuesta->Sat) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Sat->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Sat->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Sat->Sugerencias);

    if (isset($respuesta->Sat->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Sat->Validaciones);
    }

    echo Get_Html_Group('SAT', $body);
}

// Método que muestra las validaciones hechas al domicilio del EMISOR
function Show_Sepomex_Emisor($respuesta)
{
    if (isset($respuesta->Sepomex) == false) {
        return;
    }

    if (isset($respuesta->Sepomex->Emisor) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Sepomex->Emisor->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Sepomex->Emisor->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Sepomex->Emisor->Sugerencias);

    if (isset($respuesta->Sepomex->Emisor->CodigoPostal)) {
        $body = $body . Get_Html_Row('Código postal', $respuesta->Sepomex->Emisor->CodigoPostal);
    }

    if (isset($respuesta->Sepomex->Emisor->Colonia)) {
        $body = $body . Get_Html_Row('Colonia', $respuesta->Sepomex->Emisor->Colonia);
    }

    if (isset($respuesta->Sepomex->Emisor->Municipio)) {
        $body = $body . Get_Html_Row('Municipio', $respuesta->Sepomex->Emisor->Municipio);
    }

    if (isset($respuesta->Sepomex->Emisor->Estado)) {
        $body = $body . Get_Html_Row('Estado', $respuesta->Sepomex->Emisor->Estado);
    }

    if (isset($respuesta->Sepomex->Emisor->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Sepomex->Emisor->Validaciones);
    }

    echo Get_Html_Group('SEPOMEX - Emisor', $body);
}

// Método que muestra las validaciones hechas al domicilio del EMISOR
function Show_Sepomex_Receptor($respuesta)
{
    if (isset($respuesta->Sepomex) == false) {
        return;
    }

    if (isset($respuesta->Sepomex->Receptor) == false) {
        return;
    }

    $body = Get_Html_Row('Errores', $respuesta->Sepomex->Receptor->Errores) . Get_Html_Row('Advertencias',
            $respuesta->Sepomex->Receptor->Advertencias) . Get_Html_Row('Sugerencias', $respuesta->Sepomex->Receptor->Sugerencias);

    if (isset($respuesta->Sepomex->Receptor->CodigoPostal)) {
        $body = $body . Get_Html_Row('Código postal', $respuesta->Sepomex->Receptor->CodigoPostal);
    }

    if (isset($respuesta->Sepomex->Receptor->Colonia)) {
        $body = $body . Get_Html_Row('Colonia', $respuesta->Sepomex->Receptor->Colonia);
    }

    if (isset($respuesta->Sepomex->Receptor->Municipio)) {
        $body = $body . Get_Html_Row('Municipio', $respuesta->Sepomex->Receptor->Municipio);
    }

    if (isset($respuesta->Sepomex->Receptor->Estado)) {
        $body = $body . Get_Html_Row('Estado', $respuesta->Sepomex->Receptor->Estado);
    }

    if (isset($respuesta->Sepomex->Receptor->Validaciones)) {
        $body = $body . Show_Validaciones($respuesta->Sepomex->Receptor->Validaciones);
    }

    echo Get_Html_Group('SEPOMEX - Receptor', $body);
}


// Método que muestra los datos del archivo validado
function Show_Cfdi_Sat($respuesta)
{
    // {"ProcessProviderResult":1,"Version":1.0,"Status":4,"FechaCancelacion":"2014-11-14T12:24:47"}
    $body =
        Get_Html_Row('Version', $respuesta->Version) .
        Get_Html_Row('ProcessProviderResult', $respuesta->ProcessProviderResult);

    switch ($respuesta->Status) {
        case 1:
            $body = Get_Html_Row('Status en el SAT', 'Desconocido');
            break;

        case 2:
            $body = Get_Html_Row('Status en el SAT', 'No encontrado');
            break;

        case 3:
            $body = Get_Html_Row('Status en el SAT', 'Activo');
            break;

        case 4:
            $body =
                Get_Html_Row('Status en el SAT', 'Cancelado') .
                Get_Html_Row('Fecha de cancelacion', $respuesta->FechaCancelacion);
            break;
    }

    if (isset($respuesta->ErrorDescription)) {
        $body = Get_Html_Row('ErrorDescription', $respuesta->ErrorDescription);
    }


    echo Get_Html_Group('Resultado', $body);
}

// Método que muestra los datos del archivo validado
function Show_Estado_Cuenta($respuesta)
{
    //  {"ProcessProviderResult":1,"Version":1.0,"Status":"1","Comprados":1000,"Consumidos":201,"Disponibles":799,"FechaCaducidad":"2020-04-23T23:59:59"}
    $body =
        Get_Html_Row('Version', $respuesta->Version) .
        Get_Html_Row('ProcessProviderResult', $respuesta->ProcessProviderResult);

    $date = date_create($respuesta->FechaCaducidad);

    $body =
        Get_Html_Row('Status', $respuesta->Status == 1 ? 'Activo' : 'Deshabilitado') .
        Get_Html_Row('Comprados', number_format($respuesta->Comprados)) .
        Get_Html_Row('Consumidos', number_format($respuesta->Consumidos)) .
        Get_Html_Row('Disponibles', number_format($respuesta->Disponibles)) .
        Get_Html_Row('Fecha caducidad', date_format($date, 'd/m/Y'))
    ;

    echo Get_Html_Group('Resultado', $body);
}

function Validate_Activation($idDistribuidor)
{
    if (empty($idDistribuidor) == false)
        return;

    $chronometer = new Chronometer();
    $tipo = 'ACTIVACION';
    $message1 = 'Ponte en contacto con <a href="https://www.facturando.mx" target="_blank">nosotros</a> para poder proporcionarte un <strong>IDENTIFICADOR</strong> y puedas realizar pruebas.';
    $message2 = "<strong>ACTIVACION DEL SERVICIO</strong>";
    include_once(__DIR__ . '/../../codigo/view/view_error.php');
    die;
}