<?php

/**
 * Created by Facturando.
 * Date: 2019.07.11
 * Issue:
 *   Ejemplo que muestra como consultar el estado de cuenta de un distribuidor
 *      - Status del distribuidor
 *      - Créditos Comprados
 *      - Créditos consumidos
 *      - Créditos disponibles
 *      - Fecha de caducidad
 */

header('Content-type: text/html; charset=utf-8');

include_once(__DIR__ . '/../../codigo/estadocuenta.php');
include_once(__DIR__ . '/../../codigo/clases/types.class.php');

// Estos "include" solamente son usados para este ejemplo
include_once(__DIR__ . '/../../codigo/includes/helpers.php');
include_once(__DIR__ . '/../../codigo/includes/chronometer.class.php');

// Instanciamos la clase Chronometer para medir el tiempo de ejecución del proceso.
$chronometer = new Chronometer();

use HyperSoft\ElectronicDocument\Validator;

// Ponte en contacto con nosotros para proporcionarte tu ID y poder ejecutar este ejemplo
$rfcDistribuidor = '';
$idDistribuidor = '';

// Este código solamente se usa para este ejemplo y sirve
// para saber si ya tienes tu ID de distribuidor y poder usar el servicio
Validate_Activation($idDistribuidor);

// 1. Instanciamos la clase cfdisat que es la que se encarga de ejecutar la consulta
$estadoCuenta = new Validator\EstadoCuenta($rfcDistribuidor, $idDistribuidor);

// 3. Ejecutamos el proceso y obtenemos un objeto con la respuesta
//    retornada por el web service
$respuesta = $estadoCuenta->Execute();

$chronometer->Stop();

//4. Verificamos la respuesta del servidor y mostramos los datos en pantalla.
switch ($respuesta->ProcessProviderResult) {
    case Validator\ProcessProviderResult::Ok:
        $tipo = 'Ok';
        $message1 = "El proceso fue ejecutado correctamente";
        include_once("view.php");
        return;

    case Validator\ProcessProviderResult::ErrorInDocument:
        $tipo = 'ErrorInDocument';
        $message1 = 'El proceso no pudo ser ejecutado porque existen errores en los datos enviados';
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorInConnection:
        $tipo = 'ErrorWithProvider';
        $message1 = 'El proceso no pudo ser ejecutado porque se generó un error en la comunicación con el servidor de validación.';
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorWithProvider:
        $tipo = 'ErrorWithProvider';
        $message1 = "Se realizó la conexión con el servidor de Facturando, pero este retorno un error.";
        $message2 = "<strong>{$respuesta->ErrorNumber} - {$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorWithJson:
        $tipo = 'ErrorWithJson';
        $message1 = 'El proceso no pudo ser ejecutado, el servidor no recibió el JSON con la estructura esperada.';
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorHttp:
        $tipo = 'ErrorHttp';
        $message1 = "El proceso no pudo ser ejecutado porque se generó un error en la comunicación con el servidor";
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";

        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    default:
        throw new UnexpectedValueException();
        break;
}