<?php

/**
 * Created by Facturando.
 * Date: 2019.07.11
 * Issue:
 *   Ejemplo que muestra como validar un CFDI
 */


header('Content-type: text/html; charset=utf-8');

include_once(__DIR__ . '/../../codigo/edv.php');
include_once(__DIR__ . '/../../codigo/clases/parametros/timbre.class.php');
include_once(__DIR__ . '/../../codigo/clases/parametros/certificado.class.php');
include_once(__DIR__ . '/../../codigo/clases/parametros/documento.class.php');
include_once(__DIR__ . '/../../codigo/clases/parametros/json.class.php');
include_once(__DIR__ . '/../../codigo/clases/parametros/timbre.class.php');
include_once(__DIR__ . '/../../codigo/includes/helpers.php');
include_once(__DIR__ . '/../../codigo/includes/chronometer.class.php');

// Instanciamos la clase Chronometer para medir el tiempo de ejecución del proceso.
$chronometer = new Chronometer();

use HyperSoft\ElectronicDocument\Validator\Parametros;
use HyperSoft\ElectronicDocument\Validator;

// Archivo XML a validar
const FILE_NAME = 'ejemplo.xml';
//const FILE_NAME = 'fatal_error.xml';

// Ponte en contacto con nosotros para proporcionarte tu ID y poder ejecutar este ejemplo
$rfcDistribuidor = '';
$idDistribuidor = '';

// Este código solamente se usa para este ejemplo y sirve
// para saber si ya tienes tu ID de distribuidor y poder usar el servicio
Validate_Activation($idDistribuidor);


// 1. Instanciamos la clase EDV que es la que se encarga de ejecutar la validación del archivo XML
$edv = new Validator\Edv($rfcDistribuidor, $idDistribuidor);

// 2. Leemos el archivo XML en una variable y lo codificamos en Base 64
$xml = file_get_contents_utf8(FILE_NAME);
$edv->Xml = base64_encode($xml);

// 3. Asignamos los diferentes parámetros que se usan durante el proceso de validación,
//    si desea conocer más acerca de los mismos, le recomendamos leer el archivo
//    documentacion\Layout PHP de validacion - Informacion.xlsx que se encuentra en la
//    carpeta documentación y en el cual se describen cada uno de los parámetros, su tipo
//    y obligatoriedad.
$edv->FileName = FILE_NAME;
$edv->Identar = true;
$edv->ReportePdf = true;
$edv->AmountEpsilon = 0.99;
$edv->DocumentToStamp = 0;

// 3.1 Parámetro que indica si se van a soportar otros formatos en la fecha del documento,
//     por ejemplo, activando esta propiedad las siguientes fechas serían válidas:
//       . 2015-05-04T09:44:12.06-05:00
//       . 2015-05-04T09:44:12.06+05:00
//       . 2015-05-04T09:44:12.1
//     Se recomienda dejarlo en true
$edv->SupportFormatsOnDate = true;


// 3.2 Parámetro para indicar el RFC de la empresa y con esto poder verificar si el
//     comprobante validado fue emitido por o para esta empresa.
$edv->EnterpriseRfc = "AAAD770905441";

// 3.3 Parámetro para indicar si NO SE DESEA ejecutar la validación del XML contra los
//     schemas publicados por el SAT
//$edv->DisableSchemaValidation = true;

// 4. Los parámetros que se describen a continuación están enfocados a modificar la respuesta (datos)
//   que retorna el Web Service, se recomienda solamente usar estos parámetros cuando realmente sea requerido.
/*$documento = new Parametros\Documento();
$documento->Documento = true;
$documento->NumeroCertificado = true;
$documento->Sello = true;
$documento->CadenaOriginal = true;
$documento->CadenaOriginalPac = true;
$edv->Documento = $documento;

$timbre = new Parametros\Timbre();
$timbre->NumeroCertificadoSat = true;
$timbre->SelloCfd = true;
$timbre->SelloSat = true;
$edv->Timbre = $timbre;

$certificado = new Parametros\Certificado();
$certificado->Version = true;
$certificado->EmitidoPor = true;
$edv->Certificado = $certificado;
*/

// 5. Ejecutamos el proceso de validación y obtenemos un objeto con la respuesta
//    retornada por el web service de validación.
$respuesta = $edv->Execute();

$chronometer->Stop();

include_once(__DIR__ . "/../../codigo/clases/types.class.php");

//6. Verificamos la respuesta del servidor y mostramos los datos en pantalla.
switch ($respuesta->ProcessProviderResult) {
    case Validator\ProcessProviderResult::Ok:
        $tipo = 'Ok';
        $message1 = "El proceso fue ejecutado correctamente";
        include_once("view.php");
        return;

    case Validator\ProcessProviderResult::ErrorInDocument:
        $tipo = 'ErrorInDocument';
        $message1 = 'El proceso no pudo ser ejecutado porque existen errores en los datos enviados';
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorInConnection:
        $tipo = 'ErrorWithProvider';
        $message1 = 'El proceso no pudo ser ejecutado porque se generó un error en la comunicación con el servidor de validación.';
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorWithProvider:
        $tipo = 'ErrorWithProvider';
        $message1 = "Se realizó la conexión con el servidor de Facturando, pero este retorno un error.";
        $message2 = "<strong>{$respuesta->ErrorNumber} - {$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorWithJson:
        $tipo = 'ErrorWithJson';
        $message1 = 'El proceso no pudo ser ejecutado, el servidor no recibió el JSON con la estructura esperada.';
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";
        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    case Validator\ProcessProviderResult::ErrorHttp:
        $tipo = 'ErrorHttp';
        $message1 = "El proceso no pudo ser ejecutado porque se generó un error en la comunicación con el servidor";
        $message2 = "<strong>{$respuesta->ErrorDescription}</strong>";

        include_once(__DIR__ . '/../../codigo/view/view_error.php');
        return;

    default:
        throw new UnexpectedValueException();
        break;
}